#########
Tutorials
#########

There are several tutorials to help guide uses through the concepts of build123d
in a step by step way. Working through these tutorials in order is recommended
as later tutorials build on the concepts introduced in earlier ones.

.. toctree::
    :maxdepth: 2

    tutorial_design.rst
    tutorial_selectors.rst
    tutorial_lego.rst
    tutorial_joints.rst
    examples_1.rst
    tttt.rst
    tutorial_surface_modeling.rst
